html {
	height: 100%;
}

body {
	margin:0;
	padding:0;
	height:100%;
	background-color:#FAFAEC;
}

.row #output-column, #editor-column, #graphics-column {
    height:100%;
}

.container-fluid {
    height:100%;
}

span.hidden
{
   display: none;
}

#nav-row {
    padding-top:5px;
    padding-left:0;
    padding-right:0;
}

#console-nav-row {
    padding-top:5px;
    padding-left:0;
    padding-right:0;
    text-align:right;
}

#body-row {
    height:84%;
    padding-left:10px;
}

#output-column, #editor-column, #graphics-column, #legal-column {
    padding-left:10x;
    padding-right:10px;
    padding-bottom:10px;
}


#loading {
    color:red;
}

#source_filename {
    width:150px;
}

#bottom-row {
    padding-left:10px;
    padding-right:10px;
}

#footer-row, #legalese-row {
    padding:10px;
}

#footer-row {
    text-align:right;
}

#legalese-row {
    text-align:left;
}

#console, #code {
    width:100%;
    height:100%;
    box-sizing: border-box;
    margin-top:15px;
    margin-left:-10px;
    font-family: "Lucida Console", Monaco, monospace; 
    font-size:10pt;
 } 


#ggame-canvas {
    width:100%;
    height:auto;
    box-sizing: border-box;
    margin-top:15px;
    background-color:#ffffff;
    border: 1px solid #DDD;
} 


/* ACE EDITOR */
 
#editorace  { 
    position:relative;
    top:0;
    right:0;
    bottom:0;
    left:0;
    height:100%;
    width:100%;
    border: 1px solid #DDD;
    border-radius: 4px;
    border-bottom-right-radius: 0px;
    margin-top:15px;
    margin-left:-10px;
    font-family: "Lucida Console", Monaco, monospace; 
    font-size:10pt;
}


