<div class="col-md-6" id="legalese-row">
    <a href = "{{ url_for('legalnotices', filename='privacy') }}">privacy policy</a> :: 
    <a href = "{{ url_for('legalnotices', filename='cookies') }}">cookies</a> ::
    <a href = "{{ url_for('legalnotices', filename='termsofservice') }}">terms of service</a> ::
    <a href = "mailto: {{ contact }}">contact</a>
</div>
